pub fn parse_session_file(
path: &Path,
workspace_id: &str,
) -> Result<ChatSession, CopilotError>Expand description
Parse a chat session from a JSON file
Errors
Returns an error if the file cannot be read or parsed.
pub fn parse_session_file(
path: &Path,
workspace_id: &str,
) -> Result<ChatSession, CopilotError>Parse a chat session from a JSON file
Returns an error if the file cannot be read or parsed.